<?php
// Script d'installation de Cahier de Prépa
// Vérifie la configuration et l'existence de la base de données
// Aide à l'installation et à la configuration

// Recharge de la page si elle est lancée par un autre script
// Remarque : on peut être dans une fonction (premiere_connexion) -> $GLOBALS !
if ( defined('OK') )  {
  $proto = ( $GLOBALS['https'] ) ? 'https://' : 'http://';
  header("Location: $proto${GLOBALS['site']}/installation");
  exit();
}

// Headers HTML
$header = <<<FIN
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">
<html>
<head>
  <title>Cahier de Prépa : installation</title>
  <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
  <link rel="stylesheet" href="css/style.css" type="text/css" media="screen">
  <link rel="stylesheet" href="css/couleurs.css" type="text/css" media="screen">
</head>
<body>

<h1>Cahier de Prépa&nbsp;: installation</h1>

<div class="item">
  <h3>Bienvenue sur <a href="http://cahier-de-prepa.fr">Cahier de Prépa</a> et merci d'essayer ce gestionnaire de site&nbsp;!</h3>
  <p><a href="http://cahier-de-prepa.fr">Cahier de Prépa</a> est un gestionnaire de sites web pour la communication des professeurs vers leurs élèves de CPGE. Il permet de&nbsp;:</p>
  <ul>
    <li>Faire passer des informations de façon rapide sur des thèmes précis grâce à des pages dédiées</li>
    <li>Annoncer le programme de colle (pour les élèves et les colleurs)</li>
    <li>Tenir à jour le cahier de texte</li>
    <li>Mettre à disposition les documents distribués ou non</li>
  </ul>
</div>

FIN;
$footer = <<<FIN

</body>
</html>
FIN;

///////////////////////////////
// Première vérifications, bloquantes : le fichier de configuration est ok
///////////////////////////////
if ( file_exists('config.php') && is_readable('config.php') )
  include('config.php');
else
  exit($header.'<h3 class="warning admin">Le fichier de configuration n\'existe pas ou n\'est pas lisible. Il doit s\'appeler config.php, se trouver au même endroit que l\'ensemble des fichiers constituant le site et être lisible par l\'utilisateur d\'Apache (<code>'.`whoami | tr -d '\n'`.'</code>).</h3>'.$footer);
// Vérification des données du fichier de configuration
if ( !isset($site) || !isset($siteadmin) || !isset($classe) || !isset($lycee) || !isset($https) || !isset($base) || !isset($mdp) )
  exit($header.'<h3 class="warning admin">Le fichier de configuration est incomplet, il manque des données nécessaire au fonctionnement du site. Il faut le modifier manuellement.</h3>'.$footer);
if ( strlen($base) > 12 )
  exit($header.'<h3 class="warning admin">Le nom de la base de données est trop long. Il ne doit pas être supérieur à 12 caractères. Il faut corriger cela dans le fichier de configuration manuellement.</h3>'.$footer);

///////////////////////////////
// Connexion obligatoire à partir d'ici, en entrant le mot de passe du fichier de configuration
///////////////////////////////
session_start();
if ( isset($_SESSION[md5($site)]) )  {
  if ( !isset($_REQUEST['deconnexion']) && ( $_SESSION['client'] == $_SERVER['HTTP_USER_AGENT'] ) && ( $_SESSION['ip'] == $_SERVER['REMOTE_ADDR'] ) )
    $admin = true;
  else  $admin = false;
}
elseif ( isset($_REQUEST['motdepasse']) && ( $_REQUEST['motdepasse'] == $mdp ) )  {
  $admin = true;
  // Interdiction de garder son identifiant de session
  session_regenerate_id(true);
  $_SESSION = array();
  // Pour vérification aux connexions ultérieures
  $_SESSION[md5($site)] = true;
  $_SESSION['client'] = $_SERVER['HTTP_USER_AGENT'];
  $_SESSION['ip'] = $_SERVER['REMOTE_ADDR'];
}
else  $admin = false;
if ( !$admin )  {
  $_SESSION = array();
  setcookie(session_name(),'',time()-3600);
  session_regenerate_id(true);
  echo <<<FIN
$header
<form class="warning admin" action="" method="post">
  <h3>Pour aller plus loin, vous devez entrer le mot de passe contenu dans le fichier de configuration.</h3>
  <p><input type="password" name="motdepasse"> <input type="submit" name="Ok" value="Envoyer"></p>
</form>
$footer
FIN;
  exit();
}
// Autoriser la connexion directe à l'interface d'administration uniquement si l'utilisateur et la matière sont définis (passage par l'étape 2)
$_SESSION['time'] = ( isset($_SESSION['ip']) ) ? time()+900 : time();

///////////////////////////////
// Codes MySQL des différentes étapes
///////////////////////////////
$code_etape1 = <<<FIN
DROP DATABASE IF EXISTS `$base`;
CREATE DATABASE `$base` DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;
DELETE FROM mysql.user WHERE User = '$base' OR User = '$base-adm';
INSERT INTO mysql.user (Host, User, Password) 
  VALUES ('$serveur', '$base', PASSWORD('$mdp')),
         ('$serveur', '$base-adm', PASSWORD('$mdp'));
DELETE FROM mysql.db WHERE Db = '$base';
INSERT INTO mysql.db (Host, Db, User, Select_priv, Insert_priv, Update_priv, Delete_priv, Alter_priv) 
  VALUES ('$serveur', '$base', '$base', 'Y', 'N', 'N', 'N', 'N'),
         ('$serveur', '$base','$base-adm', 'Y', 'Y', 'Y', 'Y', 'Y');
FLUSH PRIVILEGES;

USE `$base`;
CREATE TABLE `matieres` (
  `id` tinyint(3) unsigned NOT NULL PRIMARY KEY AUTO_INCREMENT,
  `ordre` tinyint(3) unsigned NOT NULL,
  `cle` varchar(20) NOT NULL,
  `nom` varchar(30) NOT NULL,
  `colles` tinyint(1) unsigned NOT NULL,
  `agenda` tinyint(1) unsigned NOT NULL,
  `docs` tinyint(1) unsigned NOT NULL,
  KEY `colles` (`colles`),
  KEY `agenda` (`agenda`),
  KEY `docs` (`docs`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

CREATE TABLE `utilisateurs` (
  `id` tinyint(3) unsigned NOT NULL PRIMARY KEY AUTO_INCREMENT,
  `nom` varchar(20) NOT NULL,
  `mdp` char(40) NOT NULL,
  `matiere` tinyint(3) unsigned NOT NULL
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

CREATE TABLE `pages` (
  `id` tinyint(3) unsigned NOT NULL PRIMARY KEY AUTO_INCREMENT,
  `ordre` tinyint(3) unsigned NOT NULL,
  `cle` varchar(20) NOT NULL,
  `nom` varchar(30) NOT NULL,
  `titre` text NOT NULL,
  `bandeau1` text NOT NULL,
  `bandeau2` text NOT NULL
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

CREATE TABLE `infos` (
  `id` tinyint(3) unsigned NOT NULL,
  `page` tinyint(3) unsigned NOT NULL,
  `cache` tinyint(1) unsigned NOT NULL,
  `titre` text NOT NULL,
  `texte` text NOT NULL,
  PRIMARY KEY (`id`,`page`),
  KEY `cache` (`cache`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

CREATE TABLE `semaines` (
  `lundi` date NOT NULL PRIMARY KEY,
  `colle` tinyint(3) NOT NULL,
  `pascolle` tinyint(3) NOT NULL,
  KEY `colle` (`colle`),
  KEY `pascolle` (`pascolle`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

CREATE TABLE `colles` (
  `id` tinyint(3) unsigned NOT NULL,
  `matiere` tinyint(3) unsigned NOT NULL,
  `texte` text NOT NULL,
  PRIMARY KEY (`id`,`matiere`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

CREATE TABLE `agenda` (
  `id` smallint(5) unsigned NOT NULL PRIMARY KEY AUTO_INCREMENT,
  `matiere` tinyint(3) unsigned NOT NULL,
  `jour` date NOT NULL,
  `h_debut` time NOT NULL,
  `h_fin` time NOT NULL,
  `pour` date NOT NULL,
  `type` tinyint(3) unsigned NOT NULL,
  `texte` text NOT NULL,
  `demigroupe` tinyint(1) unsigned NOT NULL,
  KEY `jour` (`jour`),
  KEY `type` (`type`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

CREATE TABLE `agenda-types` (
  `id` tinyint(3) unsigned NOT NULL PRIMARY KEY AUTO_INCREMENT,
  `ordre` tinyint(3) unsigned NOT NULL,
  `cle` varchar(20) NOT NULL,
  `nom` varchar(30) NOT NULL,
  `titre` varchar(40) NOT NULL,
  `h_fin` tinyint(1) unsigned NOT NULL
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

CREATE TABLE `agenda-boutons` (
  `id` tinyint(3) unsigned NOT NULL,
  `matiere` tinyint(3) unsigned NOT NULL,
  `nom` varchar(40) NOT NULL,
  `jour` tinyint(3) unsigned NOT NULL,
  `h_debut` time NOT NULL,
  `h_fin` time NOT NULL,
  `type` tinyint(3) unsigned NOT NULL,
  `demigroupe` tinyint(1) unsigned NOT NULL,
  PRIMARY KEY (`id`,`matiere`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

CREATE TABLE `repertoires` (
  `id` smallint(5) unsigned NOT NULL PRIMARY KEY AUTO_INCREMENT,
  `matiere` tinyint(3) unsigned NOT NULL,
  `nom` varchar(100) NOT NULL,
  `titre` varchar(100) NOT NULL,
  KEY `matiere` (`matiere`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

CREATE TABLE `documents` (
  `id` smallint(5) unsigned NOT NULL PRIMARY KEY AUTO_INCREMENT,
  `repertoire` tinyint(3) unsigned NOT NULL,
  `nom` varchar(100) NOT NULL,
  `titre` varchar(100) NOT NULL,
  `dateupload` date NOT NULL,
  `taille` varchar(12) NOT NULL,
  `lien` tinyint(1) NOT NULL,
  KEY `repertoire` (`repertoire`),
  KEY `lien` (`lien`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

FIN;
$code_etape2 = <<<FIN
DELETE FROM matieres;
INSERT INTO matieres (ordre,cle,nom,colles,agenda) VALUES (1,'[cle_matiere]','[nom_matiere]',1,1);
DELETE FROM utilisateurs;
INSERT INTO utilisateurs (nom,mdp,matiere) VALUES ('[utilisateur]',SHA1('[mot_de_passe]'),1);

FIN;
$c = addslashes($classe);
$l = addslashes($lycee);
$code_etape3 = <<<FIN
DELETE FROM pages;
INSERT INTO pages (ordre,cle,nom,titre,bandeau1,bandeau2)
  VALUES (1,'accueil','Accueil','','Dernières informations importantes&nbsp;:','Bienvenue sur le site dédié à la classe $c du lycée $l. Il n\'y a pas d\'information actuellement.');
DELETE FROM `agenda-types`;
INSERT INTO `agenda-types` (ordre,cle,nom,titre,h_fin)
  VALUES (1,'cours','Cours','Cours',1),
         (2,'td','TD','Séance de travaux dirigés',1),
         (3,'tp','TP','Séance de travaux pratiques',1),
         (4,'ds','DS','Devoir surveillé',1),
         (5,'interro','Interros','Interrogation de cours',0),
         (6,'distrib','Distributions','Distribution de document',0),
         (7,'dm','DM','Devoir maison',0),
         (8,'afaire','Travail à faire','Travail à faire',0);
DELETE FROM semaines;

FIN;
if ( isset($_REQUEST['niveau']) )  {
  if ( $_REQUEST['niveau'] == 'sup' )
    $code_etape3 .= <<<FIN
INSERT INTO semaines (lundi, colle, pascolle) VALUES
  ('2011-09-05', 0, 1),('2011-09-12', 0, 1),('2011-09-19', 0, 1),('2011-09-26', 1, 0),('2011-10-03', 2, 0),('2011-10-10', 3, 0),('2011-10-17', 4, 0),
  ('2011-10-24', 0, 2),('2011-11-03', 0, 1),('2011-11-07', 5, 0),('2011-11-14', 6, 0),('2011-11-21', 7, 0),('2011-11-28', 8, 0),('2011-12-05', 9, 0),
  ('2011-12-12',10, 0),('2011-12-19', 0, 3),('2012-01-03',11, 0),('2012-01-09',12, 0),('2012-01-16',13, 0),('2012-01-23',14, 0),('2012-01-30',15, 0),
  ('2012-02-06',16, 0),('2012-02-13',17, 0),('2012-02-20', 0, 4),('2012-03-05',18, 0),('2012-03-12',19, 0),('2012-03-19',20, 0),('2012-03-26',21, 0),
  ('2012-04-02',22, 0),('2012-04-10',23, 0),('2012-04-16', 0, 5),('2012-04-30',24, 0),('2012-05-07',25, 0),('2012-05-14',26, 0),('2012-05-21',27, 0),
  ('2012-05-29',28, 0),('2012-06-04',29, 0),('2012-06-11',30, 0),('2012-06-18', 0, 1),('2012-06-25', 0, 1),('2012-06-29', 0, 6);

FIN;
  else
    $code_etape3 .= <<<FIN
INSERT INTO semaines (lundi, colle, pascolle) VALUES
  ('2011-09-05', 0, 1),('2011-09-12', 1, 0),('2011-09-19', 2, 0),('2011-09-26', 3, 0),('2011-10-03', 4, 0),('2011-10-10', 5, 0),('2011-10-17', 6, 0),
  ('2011-10-24', 0, 2),('2011-11-03', 0, 1),('2011-11-07', 7, 0),('2011-11-14', 8, 0),('2011-11-21', 9, 0),('2011-11-28',10, 0),('2011-12-05',11, 0),
  ('2011-12-12',12, 0),('2011-12-19', 0, 3),('2012-01-03',13, 0),('2012-01-09',14, 0),('2012-01-16',15, 0),('2012-01-23',16, 0),('2012-01-30',17, 0),
  ('2012-02-06',18, 0),('2012-02-13',19, 0),('2012-02-20', 0, 4),('2012-03-05',20, 0),('2012-03-12',21, 0),('2012-03-19',22, 0),('2012-03-26',23, 0),
  ('2012-04-02',24, 0),('2012-04-10',25, 0),('2012-04-16', 0, 6);

FIN;
}

///////////////////////////////
// Installation
///////////////////////////////
if ( isset($_REQUEST['etape']) )  {
  switch ( $_REQUEST['etape'] )  {
    case 1:
      $mysqli = new mysqli($serveur,'root',$_REQUEST['mdp'],'mysql');
      if ( $mysqli->connect_errno )
        $message = 'La connexion à la base de données est impossible. Le mot de passe root est certainement faux. Erreur MySQL n°'.$mysqli->connect_errno.', «'.$mysqli->connect_error.'».';
      else  {
        $mysqli->set_charset('utf8');
        $mysqli->multi_query($code_etape1);
        $mysqli->close();
        // Pour prendre en compte le flush privileges avant d'aller plus loin
        sleep(1);
      }
    break;
    case 2:
      if ( strlen($_REQUEST['mdp1']) && ( $_REQUEST['mdp1'] == $_REQUEST['mdp2'] ) )  {
        $mysqli = new mysqli($serveur,"$base-adm",$mdp,$base);
        $mysqli->set_charset('utf8');
        $user = $mysqli->real_escape_string($_REQUEST['user']);
        $clemat = $mysqli->real_escape_string($_REQUEST['cle_mat']);
        $code_etape2 = str_replace('[mot_de_passe]',$_REQUEST['mdp1'],$code_etape2);
        $code_etape2 = str_replace('[utilisateur]',$user,$code_etape2);
        $code_etape2 = str_replace('[cle_matiere]',$clemat,$code_etape2);
        $code_etape2 = str_replace('[nom_matiere]',$mysqli->real_escape_string($_REQUEST['matiere']),$code_etape2);
        $mysqli->multi_query($code_etape2);
        if ($mysqli->errno)
          $message = 'Erreur MySQL n°'.$mysqli->errno.', «'.$mysqli->error.'».';
        else  {
          $_SESSION['user'] = $user;
          $_SESSION['mat'] = $clemat;
        }
        $mysqli->close();
      }
      else
        $message = 'Le mot de passe n\'a pas correctement été entré. Il ne peut pas être vide et vous devez l\'écrire de façon identique dans les deux cases.';
    break;
    case 3:
      $mysqli = new mysqli($serveur,"$base-adm",$mdp,$base);
      $mysqli->set_charset('utf8');
      $mysqli->multi_query($code_etape3);
      if ($mysqli->errno)
        $message = 'Erreur MySQL n°'.$mysqli->errno.', «'.$mysqli->error.'».';
      $mysqli->close();
  }
}
unset($etape);

///////////////////////////////
// Vérifications
///////////////////////////////
// Étape 1 : Vérification de la connexion pour l'utilisateur "public" (en lecture)
$mysqli = new mysqli($serveur,$base,$mdp);
if ( $mysqli->connect_errno || !($mysqli->select_db($base)) )  $etape = 1;
// Vérification de la connexion pour l'utilisateur "administration" (en écriture)
else  {
  $mysqli->close();
  $mysqli = new mysqli($serveur,"$base-adm",$mdp);
  if ( $mysqli->connect_errno || !($mysqli->select_db($base)) )  $etape = 1;
  
  // Étape 1bis : Vérification de la définition des tables
  else  {
    $resultat = $mysqli->query('SHOW TABLES');
    if ( $resultat->num_rows )  {
      $tables = array('agenda','agenda-boutons','agenda-types','colles','documents','infos','matieres','pages','repertoires','semaines','utilisateurs');
      while ( $r = $resultat->fetch_row() )  $tables = array_diff($tables,$r);
      $resultat->free();
    }
    if ( !empty($tables) )  $etape = 1;
    
    // Étape 2 : Vérification de l'existence d'au moins un administrateur
    else  {
      $resultat = $mysqli->query('SELECT id FROM utilisateurs LIMIT 1');
      if ( !($resultat->num_rows) )  $etape = 2;
      
      // Étape 2bis : Vérification de l'existence d'au moins une matière
      else  {
        $resultat->free();
        $resultat = $mysqli->query('SELECT id FROM matieres LIMIT 1');
        if ( !($resultat->num_rows) )  $etape = 2;
        
        // Étape 3 : Vérification de la présence d'au moins une page
        else  {
          $resultat->free();
          $resultat = $mysqli->query('SELECT id FROM pages LIMIT 1');
          if ( !($resultat->num_rows) )  $etape = 3;
        
          // Étape 3 : Vérification de la présence d'au moins un type de séances
          else  {
            $resultat->free();
            $resultat = $mysqli->query('SELECT id FROM `agenda-types` LIMIT 1');
            if ( !($resultat->num_rows) )  $etape = 3;
          
            // Étape 3bis : Vérification de la présence d'au moins une semaine
            else  {
              $resultat->free();
              $resultat = $mysqli->query('SELECT lundi FROM semaines LIMIT 1');
              if ( !($resultat->num_rows) )  $etape = 3;
              else  $resultat->free();
            }
          }
        }
      }
    }
  }
  $mysqli->close();
}
if ( !isset($etape) )  {
  // Vérification du répertoire "documents"
  if ( !is_dir('documents') )
    $erreur[] = 'Le répertoire «&nbsp;documents&nbsp;» n\'existe pas à la racine du site web.';
  elseif ( !is_readable('documents') || !is_executable('documents') || !is_writable('documents') )
    $erreur[] = 'Le répertoire «&nbsp;documents&nbsp;» n\'a pas les bons droits d\'accès. Il doit être accessible en lecture et en écriture. Vous pouvez taper en console&nbsp;:<br>
    <code>cd '.dirname(__FILE__).' && sudo chgrp '.`id -gn | tr -d '\n'`.' documents && sudo chmod g+w documents</code>';
  else 
    $reps[] = 'Le répertoire «&nbsp;documents&nbsp;» n\'a visiblement aucun problème.';
  // Vérification du répertoire "sauvegarde"
  if ( !is_dir('sauvegarde') )
    $erreur[] = 'Le répertoire «&nbsp;sauvegarde&nbsp;» n\'existe pas à la racine du site web.';
  elseif ( !is_readable('sauvegarde') || !is_executable('sauvegarde') || !is_writable('sauvegarde') )
    $erreur[] = 'Le répertoire «&nbsp;sauvegarde&nbsp;» n\'a pas les bons droits d\'accès. Il doit être accessible en lecture et en écriture. Vous pouvez taper en console&nbsp;:<br>
    <code>cd '.dirname(__FILE__).' && sudo chgrp '.`id -gn | tr -d '\n'`.' sauvegarde && sudo chmod g+w sauvegarde</code>';
  else 
    $reps[] = 'Le répertoire «&nbsp;sauvegarde&nbsp;» n\'a visiblement aucun problème.';
  // Vérification de la quantité de données téléchargeable
  if ( '100M' != ini_get('upload_max_filesize') )
    $upload = 'Les directives d\'augmentation de la taille des documents envoyés sur le site, dans le fichier <code>.htaccess</code> ne sont visiblement pas prises en compte. Cela signifie qu\'elle est relativement faible (a priori 2 Mo), que les documents relativement lourds ne pourront pas être envoyés. Les documents classiques ne devraient cependant pas être affectés.<br> Pour modifier cela, vous devez obliger le serveur à prendre en compte les <code>.htaccess</code>. Il s\'agit en général de la directive <code>AllowOverride All</code> à mettre dans les fichiers de configuration d\'Apache.';
}

// HTML
echo $header;
echo '
<form class="bouton_ok" action="" method="post"><div><input type="submit" name="deconnexion" value="Se déconnecter"></div></form>
';
if ( isset($message) )
  echo "\n<p class=\"warning\">$message</p>\n";

// Si on est sur une des étapes d'installation : on exécute
if ( isset($etape) )  {
?>

<div class="item admin">
  <p>Vous êtes actuellement sur la page d'installation de votre <a href="http://cahier-de-prepa.fr">Cahier de Prépa</a>. Cette installation se déroule en 3 étapes&nbsp;:</p>
  <ul>
    <li>Étape n°1&nbsp;: Création des tables de la base de données et des accès internes à la base</li>
    <li>Étape n°2&nbsp;: Création d'un compte pour l'interface d'administration</li>
    <li>Étape n°3&nbsp;: Ajout des données minimales (première page, planning annuel, types de séances)</li>
  </ul>
  <p>Vous êtes actuellement à l'étape <?php echo $etape; ?>.</p>
</div>

<?php
  switch ( $etape )  {
    case 1:
?>
<div class="item admin">
  <p>La première étape de l'installation correspond à la création des tables de la base de données ainsi que des utilisateurs au sein de cette base qui permettront au site web d'accéder et de modifier les données.</p>
  <p>Ceci correspond à entrer un certain code au serveur <code>MySQL</code>, avec des droits d'administrateur sur le serveur. Vous pouvez le faire vous-même si vous le souhaitez, grâce au code ci-dessous, mais il est plus simple de le faire immédiatement et automatiquement en validant ci-dessous le mot de passe root du serveur <code>MySQL</code>. Ce mot de passe n'est noté nulle part et ne sert qu'à cette étape.</p>
</div>

<form class="warning admin" action="" method="post">
  <h4>Mot de passe root du serveur <code>MySQL</code>&nbsp;:</h4>
  <p><input type="password" name="mdp"> <input type="submit" name="Ok" value="Envoyer"><input type="hidden" name="etape" value="1"></p>
</form>

<div class="item">
  <p>Pour information, le code qui va être envoyé sur le serveur <code>MySQL</code> est le suivant&nbsp;:</p>
  <pre style="margin: 0.5em 2%; padding: 0 4%;">
<?php echo $code_etape1; ?>
  </pre>
  <p>Remarque&nbsp;: Si des données existent partiellement, elles seront automatiquement supprimées.</p>
</div>
<?php
    break;
    case 2:
?>
<div class="item admin">
  <p>Il faut maintenant créer votre compte pour vous connecter à l'interface d'administration. Le nom n'est utilisé qu'à la connexion et n'est jamais affiché sur la partie publique du site, il est donc possible de mettre un prénom ou ce que l'on veut. Les accents ne posent pas de problème. Le mot de passe est à entrer deux fois pour éviter les erreurs de saisie.</p>
  <p>Les mots de passe sont chiffrés avant d'être stockés dans la base de données&nbsp;: il n'y a donc aucun souci sur leur confidentialité. Même l'administrateur du site, l'hébergeur ou d'éventuels pirates ne pourront jamais y avoir accès. Lors de la connexion, le mot de passe entré est chiffré à son tour et ce sont les deux chiffrements qui sont comparés.</p>
  <p>Attention&nbsp;: il est très dangereux que ce mot de passe soit évident. Cela peut impliquer une connexion extérieure (par exemple, d'un élève) à cette interface où presque tout est effaçable. Des sauvegardes sont réalisées, mais il vaut mieux cependant faire attention à cela en amont. Un bon mot de passe est un mot de passe d'au moins 8 caractères contenant des lettres, des chiffres et au moins un symbole parmi «&nbsp;?&nbsp;;&nbsp;:&nbsp;!&nbsp;.&nbsp;,-&nbsp;_&nbsp;».</p>
  <p>Vous devez de plus spécifier une matière. Elle vous sera automatiquement associée dans un premier temps.</p>
  <p>Le nom complet est le nom qui sera affiché dans le menu et dans les titres des pages associées à la matière. Mettre un nom plutôt long et éventuellement en plusieurs mots est possible. Par exemple «&nbsp;Mathématiques&nbsp;», «&nbsp;Sciences Physiques&nbsp;».</p>
  <p>La clé est un mot-clé qui sera utilisé uniquement dans les adresses web vers les pages associées à la matière. Il vaut mieux que ce soit un mot unique, court et sans majuscule. Par exemple «&nbsp;maths&nbsp;», «&nbsp;physique&nbsp;».</p>
  <p>Toutes ces données seront entièrement modifiables par l'interface d'administration. D'autres utilisateurs et d'autres matières pourront aussi être créés et modifiés ultérieurement.</p>
</div>

<form action="" method="post" class="warning admin">
  <h4>Nom d'utilisateur&nbsp;: <input type="text" name="user" value="" size="20"></h4>
  <h4>Mot de passe&nbsp;: <input type="password" name="mdp1" value="">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
    Confirmation&nbsp;: <input type="password" name="mdp2" value="">
  </h4>
  <h4>Nom complet de la matière&nbsp;: <input type="text" name="matiere" value="" size="30"> &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
    Clé&nbsp;: <input type="text" name="cle_mat" value="" size="20">
  </h4>
  <p><input type="submit" name="Ok" value="Envoyer"><input type="hidden" name="etape" value="2"></p>
</form>

<div class="item">
  <p>Pour information, le code qui va être envoyé sur le serveur <code>MySQL</code> est le suivant&nbsp;:</p>
  <pre style="margin: 0.5em 2%; padding: 0 4%;">
<?php echo $code_etape2; ?>
  </pre>
  <p>Remarque&nbsp;: Si des utilisateurs ou des matières existent, ils seront automatiquement supprimés.</p>
</div>
<?php
    break;
    case 3:
?>
<div class="item admin">
  <p>Votre <a href="http://cahier-de-prépa.fr">Cahier de Prépa</a> a besoin pour fonctionner correctement d'un minimum de données&nbsp;:</p>
  <ul>
    <li>Une première page d'information&nbsp;: vous aurez la possibilité d'afficher plusieurs pages d'informations sur des sujets différents, dont vous pourrez modifier les titres et les contenus. Une page au minimum est nécessaire, la définition d'une page d'accueil sera entrée.</li>
    <li>Des types de séances pour le cahier de texte. Ces types servent à différentier, dans les cahiers de texte de toutes les matières, les différentes séances (cours, TD, TP...). Un jeu de type sera défini.</li>
    <li>Le planning annuel, c'est-à-dire la liste des semaines. Ce planning sert à la fois pour les cahiers de texte où les affichages sont organisés par semaine de cours et dans les programmes de colles où le programme affiché est automatiquement sélectionné en fonction du jour de l'année. Le planning qui sera entré est un planning général de 30 semaines de colles pour les Sups ou de 26 semaines pour les Spés, à modifier si besoin.</li>
  </ul>
  <p>Toutes ces données seront entièrement modifiables ultérieurement dans l'interface d'administration. Il s'agit simplement d'une base minimale pour le bon fonctionnement du site.</p>
  <form action="" method="post">
    <p>Niveau&nbsp;:
      <select name="niveau"><option value="sup">Sup</option><option value="spe">Spé</option></select>
      <input type="submit" name="Ok" value="Envoyer"><input type="hidden" name="etape" value="3">
    </p>
  </form>
</div>

<div class="item">
  <p>Pour information, le code qui va être envoyé sur le serveur <code>MySQL</code> est le suivant&nbsp;:</p>
  <pre style="margin: 0.5em 2%; padding: 0 4%;">
<?php echo $code_etape3; ?>
  </pre>
  <p>Le planning annuel est légèrement différent en spé, il contient 25 semaines et s'arrête aux vacances de Pâques.</p>
  <p>Remarque&nbsp;: Si des pages, des types de séances ou des semaines existent, ils seront automatiquement supprimés.</p>
</div>

<?php  
  }
}
// Sinon, on affiche la configuration et on regarde l'état des répertoires documents et sauvegarde
else  {
  $proto = ( $https ) ? 'https://' : 'http://';
  $site = ( strlen($siteadmin) ) ? $siteadmin : "$site/?admin";
?>

<div class="item admin">
  <h3>Votre <a href="http://cahier-de-prepa.fr">Cahier de Prépa</a> est correctement installé.</h3>
  <p>Vous pouvez le modifier grâce à <a href="<?php echo $proto.$site; ?>">l'interface d'administration</a>.</p>
</div>

<div class="item">
  <h3>Vérification des répertoires où le site doit pouvoir écrire</h3>
  <p>Le répertoire «&nbsp;documents&nbsp;» est le répertoire où vous pourrez envoyer des documents pour qu'ils soient téléchargeables par les élèves. Lorsque vous envoyez un document via le site, le site copie le document dans le répertoire&nbsp;: il doit donc pouvoir écrire à l'intérieur de ce répertoire.</p>
  <p>Le répertoire «&nbsp;sauvegarde&nbsp;» permet au site de faire des sauvegarde de la base de données. Chaque jour, au moment de la première modification d'une table, le site la sauvegarde automatiquement dans un fichier à l'intérieur du répertoire «&nbsp;sauvegarde&nbsp;»&nbsp;: il doit donc pouvoir écrire à l'intérieur de ce répertoire.</p>
</div>

<?php
  if ( isset($reps) )  {
    $reps = implode("</p>\n<p>",$reps);
    echo <<<FIN
<div class="item admin">
  <p>$reps</p>
</div>


FIN;
  }
  if ( isset($erreur) )  {
    $erreur = implode("</p>\n<p>",$erreur);
    echo <<<FIN
<div class="warning admin">
  <p>$erreur</p>
</div>


FIN;
  }
  if ( isset($upload) )
    echo <<<FIN
<div class="warning admin">
  <p>$upload</p>
</div>


FIN;
}
?>
</body>
</html>
<?php exit(); ?>
